//////////////////////////////////////////////////////////////////////////////
//	RtBONX
//////////////////////////////////////////////////////////////////////////////

#pragma once

#include <windows.h>

#include <assert.h>

#include <string>
#include <vector>
#include <boost/lexical_cast.hpp>
#include <boost/tokenizer.hpp>

#include "IniFile.h"
#include "string_ex.h"

static const char *	c_snIgnoreWords		= "IgnoreWords" ;
static const char *	c_knNum				= "Num" ;
static const char *	c_knText			= "Text" ;

class CConfig
{
public:
	// RXgN^
	CConfig( LPCSTR pszINIFilePath ):
		m_ignoreWords()
	{
		CIniFile	iniFile( pszINIFilePath ) ;
		UINT		ignoreNum = iniFile.Get<UINT>( c_snIgnoreWords, c_knNum, 0 ) ;
		if ( ignoreNum == 0 )
			return ;
		m_ignoreWords.reserve( ignoreNum ) ;
		for ( UINT i = 0 ; i < ignoreNum ; i ++ )
		{
			std::string		knText( c_knText ) ;
			knText += boost::lexical_cast<std::string>( i ) ;
			std::wstring	wstrText ;
			MakeWString( wstrText, iniFile.Get<std::string>( c_snIgnoreWords, knText.c_str(), "" ).c_str(), true ) ;
			if ( !wstrText.empty() )
				m_ignoreWords.push_back( wstrText ) ;
		}
	}

private:
	typedef std::vector<std::wstring>	WStrVec ;
	WStrVec		m_ignoreWords ;

public:
	// ҏWp̕擾
	void GetEditText( std::string & text ) const
	{
		text.clear() ;
		for ( WStrVec::const_iterator itr = m_ignoreWords.begin() ; itr != m_ignoreWords.end() ; ++ itr )
		{
			std::string	word ;
			MakeString( word, itr->c_str() ) ;
			text += word ;
			text += "\r\n" ;
		}
	}
	// ҏWp̕ݒ肷
	void SetEditText( LPCSTR pszText )
	{
		m_ignoreWords.clear() ;
		std::wstring	text ;
		MakeWString( text, pszText, true ) ;
		typedef boost::char_separator<wchar_t>	Separator ;
		typedef boost::tokenizer<Separator,std::wstring::const_iterator,std::wstring>	Tokenizer ;
		Tokenizer	tokens( text, Separator(L"\r\n") ) ;
		for ( Tokenizer::iterator itr = tokens.begin() ; itr != tokens.end() ; ++ itr )
			m_ignoreWords.push_back( itr->c_str() ) ;
	}
	// ėǂ̂ł邩ׂ
	bool IsValidName( LPCWSTR pszAttName ) const
	{
		std::wstring	attName( pszAttName ) ;
		MakeLower( attName ) ;
		for ( WStrVec::const_iterator itr = m_ignoreWords.begin() ; itr != m_ignoreWords.end() ; ++ itr )
		{
			if ( attName.find( *itr ) != std::wstring::npos )
				return false ;
		}
		return true ;
	}
	// ۑ
	void Save( LPCSTR pszINIFilePath ) const
	{
		CIniFile	iniFile( pszINIFilePath ) ;
		UINT		ignoreNum = static_cast<UINT>( m_ignoreWords.size() ) ;
		iniFile.Set<UINT>( c_snIgnoreWords, c_knNum, ignoreNum ) ;
		for ( UINT i = 0 ; i < ignoreNum ; i ++ )
		{
			std::string		knText( c_knText ) ;
			knText += boost::lexical_cast<std::string>( i ) ;
			std::string		text ;
			MakeString( text, m_ignoreWords[i].c_str() ) ;
			iniFile.Set<LPCSTR>( c_snIgnoreWords, knText.c_str(), text.c_str() ) ;
		}
	}
} ;
